@@ -1079,7 +1079,9 @@ void printRogueInformationToFile( All *tr, FILE *rogueOutput, int bestCumEver, i
       printIndexListToFile(rogueOutput, dropsetInRound[i]->taxaToDrop); 
       fprintf(rogueOutput, "\t");
       fprintRogueNames(tr, rogueOutput, dropsetInRound[i]->taxaToDrop);
-      fprintf(rogueOutput, "\t%f\t%f\n", (double)(cumScores[i]  - cumScores[i-1] )/ (double)tr->numberOfTrees,(double)cumScores[i] / (double)((computeSupport ? numberOfTrees : 1 ) * (mxtips-3)) ); 
+      fprintf(rogueOutput, "\t%f\t%f\n", 
+	      (double)(cumScores[i]  - cumScores[i-1] )/ (double)(computeSupport ? tr->numberOfTrees : 1.0),
+	      (double)cumScores[i] / (double)((computeSupport ? numberOfTrees : 1 ) * (mxtips-3)) ); 
       reached = bestCumEver == cumScores[i];
       ++i;
     }
@@ -1570,10 +1572,10 @@ Dropset *evaluateEvents(HashTable *mergingHash, Array *bipartitionsById, Array *
 	  
 	  double oldQuality =  labelPenalty == 0.0  
 	    ? result->improvement * drSize 
-	    :  (double)(result->improvement / (double)(computeSupport ?  numberOfTrees : 1.0)) - (double)resSize;
+	    :  (double)(result->improvement / (double)(computeSupport ?  numberOfTrees : 1.0)) - labelPenalty * (double)resSize;
 	  double newQuality = labelPenalty == 0.0 
 	    ? dropset->improvement * resSize
-	    : (double)(dropset->improvement / (double)(computeSupport ? numberOfTrees : 1.0)) - (double)drSize; 
+	    : (double)(dropset->improvement / (double)(computeSupport ? numberOfTrees : 1.0)) - labelPenalty * (double)drSize; 
 	  
 	  if( (newQuality  >  oldQuality) )
 	    result = dropset;	  
@@ -1584,11 +1586,15 @@ Dropset *evaluateEvents(HashTable *mergingHash, Array *bipartitionsById, Array *
   free(allDropsets->arrayTable);
   free(allDropsets);
 
-  if(labelPenalty == 0.0 && result->improvement > 0)
+  if((result->improvement / (computeSupport ? numberOfTrees : 1.0) - labelPenalty * lengthIndexList(result->taxaToDrop))  > 0.0 )
     return result;
-  else if(labelPenalty != 0.0 && (result->improvement / (computeSupport ? numberOfTrees : 1.0) - lengthIndexList(result->taxaToDrop))  > 0.0 )
-    return result; 
-  else 
+
+  /* if(labelPenalty == 0.0 && result->improvement > 0) */
+  /*   return result; */
+  /* else if(labelPenalty != 0.0 && (result->improvement / (computeSupport ? numberOfTrees : 1.0) - labelPenalty * lengthIndexList(result->taxaToDrop))  > 0.0 ) */
+  /*   return result; */
+
+  else
     return NULL;
 }
 
@@ -1917,8 +1923,7 @@ void doomRogues(All *tr, char *bootStrapFileName, char *dontDropFile, char *tree
 
   bestLastTime = cumScore;
   fprintf(rogueOutput, "num\ttaxNum\ttaxon\trawImprovement\tRBIC\n");
-  fprintf(rogueOutput, "%d\tNA\tNA\t%d\t%f\n", 0, 0, (double)cumScore /(numberOfTrees * (mxtips-3)) );
-
+  fprintf(rogueOutput, "%d\tNA\tNA\t%d\t%f\n", 0, 0, (double)cumScore /( (computeSupport ? numberOfTrees : 1 )  * (mxtips-3)) ); 
   PR("[%f] initialisation done (initScore = %f, numBip=%d)\n", updateTime(&timeInc), (double)cumScore / (double)((tr->mxtips-3) * (computeSupport ? tr->numberOfTrees : 1 ) ), bipartitionsById->length);
 
   boolean firstMerge= TRUE;
@@ -2162,7 +2167,7 @@ int main(int argc, char *argv[])
   programVersion = PROG_VERSION;
   programReleaseDate  = PROG_RELEASE_DATE;
   
-  while ((c = getopt (argc, argv, "i:t:n:x:whc:s:bT:L:")) != -1)
+  while ((c = getopt (argc, argv, "i:t:n:x:w:hc:s:bT:L:")) != -1)
     switch (c)
       {
       case 'i':
