@@ -208,7 +208,7 @@ BitVector*** getIntersectionOfRootedTriples(FILE *bootstrapFile, All *tr, int st
       
       FOR_0_LIMIT(i, tr->mxtips)
 	if( NOT NTH_BIT_IS_SET(neglectThose, i))
-	  pruneTaxon(tr, i+1);
+	  pruneTaxon(tr, i, FALSE );
       
       /* reset bit-vectors */
       FOR_0_LIMIT(i, (tr->mxtips+1))
@@ -652,7 +652,7 @@ void verifyMasts(All *tr, FILE *bootstrapFile, BitVector *taxaToKeep)
       /* prune taxa */
       for(j = 1; j <= tr->mxtips; ++j)
 	if( NOT (NTH_BIT_IS_SET(taxaToKeep, j)) )
-	  pruneTaxon(tr, j+1);
+	  pruneTaxon(tr, j, FALSE);
       
       if(i == 1 )
 	commonStart = tr->start;
@@ -701,7 +701,10 @@ void printMastToFile(All *tr, FILE *bootstrapFile,  BitVector *mast, FILE *resul
 {
   int
     droppedTaxaNum = 0, 
-    tips, i; 
+#ifdef DEBUG
+    tips,
+#endif
+    i;
 
   rewind(bootstrapFile);  
   readBootstrapTree(tr,bootstrapFile);
@@ -709,12 +712,15 @@ void printMastToFile(All *tr, FILE *bootstrapFile,  BitVector *mast, FILE *resul
   for(i = 1; i <= tr->mxtips; ++i)
     if( NOT NTH_BIT_IS_SET(mast,i) )
       {
-	pruneTaxon(tr,i+1);
+	/* printf("intending to prune: %d\n", i)	;  */
+
+	pruneTaxon(tr,i, FALSE);
 	droppedTaxaNum++;
       }
-  
+#ifdef DEBUG  
   tips = countTips(tr->start, tr->mxtips) + countTips(tr->start->back, tr->mxtips);
   assert((unsigned)tips == ((unsigned)tr->mxtips - droppedTaxaNum));
+#endif
   char *tmp = writeTreeToString(tr, FALSE);
   fprintf(result, "%s", tmp);
   printBothOpen("MAST tree: %s", tmp);
